package org.objectweb.petals.tools.juddiAdmin.connection;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.net.PasswordAuthentication;
import java.util.Collection;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Properties;
import java.util.Set;

import javax.xml.registry.BulkResponse;
import javax.xml.registry.BusinessLifeCycleManager;
import javax.xml.registry.BusinessQueryManager;
import javax.xml.registry.Connection;
import javax.xml.registry.ConnectionFactory;
import javax.xml.registry.JAXRException;
import javax.xml.registry.RegistryService;


import org.apache.ws.scout.registry.ConnectionFactoryImpl;

/**
 * This class permit to connect to a UDDI regitry and initialize the 
 * attributes which permit you to communicate with the registry.
 *  
 * @author EL JAI Mohammed
 */

public class ConnectRegistry {
	/** attributes for uddi connexion */
	@SuppressWarnings("unused")
	private String httpProxyHost = "";
	@SuppressWarnings("unused")
	private String httpProxyPort = "";
	@SuppressWarnings("unused")
	private String httpsProxyHost = "";
	@SuppressWarnings("unused")
	private String httpsProxyPort = "";
	private String regUrli = "";
	private String regUrlp = "";
	private String username = "";
	private String password = "";

	/** properties file name */
	private static final String propretiesFile = "publish.properties";

	/** attributes names in properties file (publish.propreties) */
	private static final String QUERY_URL = "query.url";
	private static final String PUBLISH_URL = "publish.url"; 
	private static final String USER_NAME = "user.name";
	private static final String USER_PASSWORD = "user.password";
	private static final String PROXY_HOST = "http.proxy.host";
	private static final String PROXY_PORT = "http.proxy.port";

	/** connexion attribues */
	private Properties connProps = new Properties();	
	private Properties publishProps;

	/** A BusinessQueryManager object allows you to search objects into a UDDI registry. */
	private BusinessQueryManager bqm;
	/** A BusinessLifeCycleManager object allows you to create objects into a UDDI registry.*/
	private BusinessLifeCycleManager blm;

	/** the single ConnectRegistry object **/
	private static ConnectRegistry connection;

	/**
	 * Return the actual connection.
	 * @param realPath : the real path of the root directory 
	 * @return a ConnectRegistry object
	 */
	public static ConnectRegistry getConnection(String realPath) {
		if(connection == null) connection = new ConnectRegistry(realPath);
		return connection;
	}


	/**
	 * Private contructor to create the single object ConnectRegistry.
	 * @param path the path of the root directory
	 */
	private ConnectRegistry(String realPath) {
		try {
			// create File object for the propreties file
			File f = new File(realPath,propretiesFile);
			// load propreties
			publishProps = new Properties();
			publishProps.load(new FileInputStream(f));

			// assign propreties
			assignUserProperties(publishProps);
			setConnectionProperties();

			// connect to registry where the paramters given in propreties file
			ConnectionFactory factory = ConnectionFactoryImpl.newInstance();
			factory.setProperties(connProps);
			Connection conn = factory.createConnection();
			PasswordAuthentication passwdAuth = new PasswordAuthentication(username, password.toCharArray());
			Set<PasswordAuthentication> creds = new HashSet<PasswordAuthentication>();
			creds.add(passwdAuth);
			conn.setCredentials(creds);

			// initilize the registry communication attributes 
			RegistryService rs = conn.getRegistryService();
			bqm = rs.getBusinessQueryManager();
			blm = rs.getBusinessLifeCycleManager();

		} catch (JAXRException e){
			System.out.println("JAXR failure" + e.getMessage());
		} catch (IOException ioe) {
			System.out.println("Can not open properties file");
		}
	}


	/**
	 * Assign attributes properties from propreties file
	 * @param props Propreties attribute
	 */
	private void assignUserProperties(Properties props) {

		String proxyHost = ((String)props.get(PROXY_HOST)).trim();
		String proxyPort = ((String)props.get(PROXY_PORT)).trim();
		String queryURL = ((String)props.get(QUERY_URL)).trim();
		String publishURL = ((String)props.get(PUBLISH_URL)).trim();
		String user = ((String)props.get(USER_NAME)).trim();
		String pw = ((String)props.get(USER_PASSWORD)).trim();

		if (proxyHost != null){
			httpProxyHost = proxyHost;
			httpsProxyHost = proxyHost;
		}
		if (proxyPort != null) {
			httpProxyPort = proxyPort;
			httpsProxyPort = proxyPort;
		}

		if (queryURL != null)
			regUrli = queryURL;

		if (publishURL != null)
			regUrlp = publishURL;

		if (user != null)
			username = user;

		if (pw != null)
			password = pw;

	}

	/**
	 * Assigne connection attributes.
	 */
	private void setConnectionProperties() {
		connProps.setProperty("javax.xml.registry.queryManagerURL",
				regUrli);
		connProps.setProperty("javax.xml.registry.lifeCycleManagerURL",
				regUrlp);        
	}


	/**
	 * Handle all exceptions genarated by the BulkResponse object.
	 * @param br
	 * @throws JAXRException
	 */
	public void handleJAXRExceptions(BulkResponse br) throws JAXRException {
		System.err.println("One or more JAXRExceptions occurred during the save operation:");
		Collection exceptions = br.getExceptions();
		Iterator iter = exceptions.iterator();
		while (iter.hasNext()) {
			Exception e = (Exception) iter.next();
			System.err.println(e.toString());
		}
	}

	/**
	 * @return the blm
	 */
	public BusinessLifeCycleManager getBlm() {
		return blm;
	}


	/**
	 * @param blm the blm to set
	 */
	public void setBlm(BusinessLifeCycleManager blm) {
		this.blm = blm;
	}


	/**
	 * @return the bqm
	 */
	public BusinessQueryManager getBqm() {
		return bqm;
	}


	/**
	 * @param bqm the bqm to set
	 */
	public void setBqm(BusinessQueryManager bqm) {
		this.bqm = bqm;
	}

}
