package org.objectweb.petals.tools.juddiAdmin.search;


import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

import javax.xml.registry.BulkResponse;
import javax.xml.registry.BusinessQueryManager;
import javax.xml.registry.JAXRException;
import javax.xml.registry.JAXRResponse;
import javax.xml.registry.infomodel.Organization;
import javax.xml.registry.infomodel.Service;

import org.objectweb.petals.tools.juddiAdmin.connection.ConnectRegistry;

/**
 * 
 * @author EL JAI Mohammed
 *
 */

public class SearchRegistryImpl implements SearchRegistry {
	
	/** connection attribute */
	private ConnectRegistry connection;
	
	/**
	 * Just initialize the connection attribute
	 * @param realPath the real path of the root directory
	 */
	public SearchRegistryImpl(String realPath) {
		this.connection = ConnectRegistry.getConnection(realPath);
	}

	/*
	 * (non-Javadoc)
	 * @see org.objectweb.petals.tools.juddiAdmin.search.SearchRegistry#findAllOrganizations()
	 */
	public List<Organization> findAllOrganizations() {
		BusinessQueryManager bqm = connection.getBqm();
		List<String> names = new ArrayList<String>();
		ArrayList<Organization> organizations = new ArrayList<Organization>();
		try {
			names.add("%%");
			BulkResponse br = bqm.findOrganizations(null,names,null,null,null,null);			
			if (br.getStatus() == JAXRResponse.STATUS_SUCCESS) {
				Collection orgs = br.getCollection();
				for (Iterator it=orgs.iterator();it.hasNext();)
				{
					Organization org = (Organization)it.next();
					organizations.add(org);
				}
			} else {
				connection.handleJAXRExceptions(br);
			}
			
		} catch (JAXRException e) {
			e.printStackTrace();
		} 
		return organizations;
	}
	
	/*
	 * (non-Javadoc)
	 * @see org.objectweb.petals.tools.juddiAdmin.search.SearchRegistry#findAllServices()
	 */
	public List<Service> findAllServices() {
		BusinessQueryManager bqm = connection.getBqm();
		List<String> names = new ArrayList<String>();
		ArrayList<Service> result_services = new ArrayList<Service>();
		try {
			
			names.add("%%");
			BulkResponse br = bqm.findOrganizations(null,names,null,null,null,null);		
			if (br.getStatus() == JAXRResponse.STATUS_SUCCESS) {
				Collection organizations = br.getCollection();
				for (Iterator it=organizations.iterator();it.hasNext();)
				{
					Organization org = (Organization)it.next();
					Collection services = org.getServices();
					for (Iterator it2=services.iterator();it2.hasNext();)
					{
						Service service = (Service) it2.next();
						result_services.add(service);
														
					}
					
				}
			} else {
				connection.handleJAXRExceptions(br);
			}
			
		} catch (JAXRException e) {
			e.printStackTrace();
		} 
		return result_services;
	}

	/*
	 * (non-Javadoc)
	 * @see org.objectweb.petals.tools.juddiAdmin.search.SearchRegistry#findOrganizationByName(java.lang.String)
	 */
	public Organization findOrganizationByName(String name) {
		BusinessQueryManager bqm = connection.getBqm();
		List<String> names = new ArrayList<String>();
		try {
			names.add("%"+name+"%");
			BulkResponse br = bqm.findOrganizations(null,names,null,null,null,null);			
			if (br.getStatus() == JAXRResponse.STATUS_SUCCESS) {
				Collection orgs = br.getCollection();
				for (Iterator it=orgs.iterator();it.hasNext();)
				{
					Organization org = (Organization)it.next();
					if(org.getName().getValue().equals(name)) {
						return org;
					}
				}
			} else {
				connection.handleJAXRExceptions(br);
			}
			
		} catch (JAXRException e) {
			e.printStackTrace();
		} 
		return null;
	}
	
	/*
	 * (non-Javadoc)
	 * @see org.objectweb.petals.tools.juddiAdmin.search.SearchRegistry#findServiceByName(java.lang.String)
	 */
	public Service findServiceByName(String name) {
		BusinessQueryManager bqm = connection.getBqm();
		List<String> names = new ArrayList<String>();
		try {
			names.add("%%");
			BulkResponse br = bqm.findOrganizations(null,names,null,null,null,null);		
			if (br.getStatus() == JAXRResponse.STATUS_SUCCESS) {
				Collection organizations = br.getCollection();
				for (Iterator it=organizations.iterator();it.hasNext();)
				{
					Organization org = (Organization)it.next();
					Collection services = org.getServices();
					for (Iterator it2=services.iterator();it2.hasNext();)
					{
						Service service = (Service) it2.next();
						if(service.getName().getValue().equals(name)) {
							return service;
						}
														
					}
					
				}
			} else {
				connection.handleJAXRExceptions(br);
			}
			
		} catch (JAXRException e) {
			e.printStackTrace();
		} 
		return null;
	}
	
	/*
	 * (non-Javadoc)
	 * @see org.objectweb.petals.tools.juddiAdmin.search.SearchRegistry#findServiceByCompany(java.lang.String, javax.xml.registry.infomodel.Organization)
	 */
	public Service findServiceByCompany(String name, Organization org) {
		try {
			Collection services = org.getServices();
			for (Iterator it2=services.iterator();it2.hasNext();) {
				Service service = (Service) it2.next();
				if(service.getName().getValue().equals(name)) {
					return service;
				}
			}
						
		} catch (JAXRException e) {
			e.printStackTrace();
		} 
		return null;
	}

}
