package org.objectweb.petals.tools.juddiAdmin.servlet;

import java.io.IOException;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.xml.registry.JAXRException;
import javax.xml.registry.infomodel.Concept;
import javax.xml.registry.infomodel.Organization;
import javax.xml.registry.infomodel.Service;

import org.objectweb.petals.tools.juddiAdmin.Object.Contact;
import org.objectweb.petals.tools.juddiAdmin.search.SearchRegistry;
import org.objectweb.petals.tools.juddiAdmin.search.SearchRegistryImpl;
import org.objectweb.petals.tools.juddiAdmin.update.UpdateRegistry;
import org.objectweb.petals.tools.juddiAdmin.update.UpdateRegistryImpl;

public final class JuddiAdminServlet extends HttpServlet {

	private static final long serialVersionUID = 6616831543123182042L;
	
	/** the name of the root directory application */
	private static final String webapp_directory = "PetalsWebAdmin";

	/** the real path of the root directory */
	private static String realPath;

	/**
	 * The empty Constructor.
	 */
	public JuddiAdminServlet() {
		super();
	}

	/**
	 * Just intialize the realPath attribute.
	 */
	public void init(ServletConfig servletConfig) throws ServletException {
		super.init(servletConfig);
		realPath = this.getServletContext().getRealPath("");

	}

	@SuppressWarnings("unchecked")
	public void doPost(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {

		// get request uri 
		String uri = request.getRequestURI();


		if(uri.equals("/"+webapp_directory+"/savePetalsService")) {
			// get request attributes
			String organizationName = request.getParameter("organization");											
			String serviceName = request.getParameter("service");
			String bindingName = request.getParameter("bindingName");
			String endPoint = request.getParameter("bindingAccessUrl");
			String wsdlUrl = request.getParameter("bindingWsdlUrl");
			String description = request.getParameter("bindingDescription");
			String interfaceWsdlDescription = request.getParameter("interfaceWsdlDescription");


			SearchRegistry search = new SearchRegistryImpl(realPath);
			UpdateRegistry update = new UpdateRegistryImpl(realPath);


			Organization org = search.findOrganizationByName(organizationName);
			Service service = search.findServiceByCompany(serviceName, org);

			try {
				// create a Jaxr concept object which groups technical information about a service
				Concept concept = update.createConcept(serviceName+"Interface",interfaceWsdlDescription,
						wsdlUrl,null);
				// save a petals service into UDDI registry
				update.createBindingTemplate(bindingName, description, endPoint, concept, service);
				getServletContext().
				getRequestDispatcher("/home.jsp").forward(request, response);
			} catch (JAXRException e) {
				e.printStackTrace();
			}
		}

		if(uri.equals("/"+webapp_directory+"/saveBusinessEntity")) {
			// get request attributes
			String entityName = request.getParameter("entityName");
			String contactName = request.getParameter("contactName");
			String contactAdress = request.getParameter("contactAdress");
			String contactEmail = request.getParameter("contactEmail");
			String contactPhone = request.getParameter("contactPhone");
			String entityDescription = request.getParameter("entityDescription");
			// create a UpdateRegistry Object
			UpdateRegistry update = new UpdateRegistryImpl(realPath);
			// create organization and save it into a UDDI registry
			try {
				update.createBusinessEntity(entityName, entityDescription, 
						new Contact(contactName,contactPhone,contactAdress,contactEmail));
				request.setAttribute("objectType", "businessEntity");
				getServletContext().
				getRequestDispatcher("/add-succeded.jsp").forward(request, response);
			} catch (JAXRException e) {
				e.printStackTrace();
			}


		}

		if(uri.equals("/"+webapp_directory+"/saveBusinessService")) {
			// get request attributes
			String organizationName = request.getParameter("organization");	
			String serviceName = request.getParameter("serviceName");
			String serviceDescription = request.getParameter("serviceDescription");
			// create a UpdateRegistry and SearchRegistry Objects
			UpdateRegistry update = new UpdateRegistryImpl(realPath);
			SearchRegistry search = new SearchRegistryImpl(realPath);
			Organization org = search.findOrganizationByName(organizationName);
			// create service and save it into a UDDI registry
			try {
				update.createBusinessService(serviceName,serviceDescription,org);
				request.setAttribute("objectType", "businessService");
				getServletContext().
				getRequestDispatcher("/add-succeded.jsp").forward(request, response);
			} catch (JAXRException e) {
				e.printStackTrace();
			}	

		}



	}

}
