package org.objectweb.petals.tools.juddiAdmin.update;


import javax.xml.registry.JAXRException;
import javax.xml.registry.infomodel.Concept;
import javax.xml.registry.infomodel.Organization;
import javax.xml.registry.infomodel.Service;


import org.objectweb.petals.tools.juddiAdmin.Object.Contact;

/**
 * This class allows you to create the flowing UDDI registry objects: 
 * BusinessService, BusinessEntity, BindingTemplate and TmodelInstance. 
 * @author EL JAI Mohammed
 *
 */



public interface UpdateRegistry {
	
	/**
	 * Create a BusinessEntity object into UDDI registry.
	 * @param name of company
	 * @param description of company
	 * @param contact of company
	 * @return true if creation succeeded 
	 */
	public boolean createBusinessEntity(String name, String description, Contact contact) throws JAXRException  ;
	
	
	/**
	 * Create a BusinessEntity object into UDDI registry.
	 * @param name of service
	 * @param description of service
	 * @param businessEntity of service
	 * return true if creation succeeded 
	 */
	public boolean createBusinessService(String name, String description, Organization org ) throws JAXRException;
	
	
	/**
	 * Create a BindingTemplate object into UDDI registry. 
	 * @param name
	 * @param description
	 * @param acessURI
	 * @return true if creation succeeded 
	 */	
	public boolean createBindingTemplate(String name, String description, String acessURI, Concept wsdlConcept, Service service) throws JAXRException;
	
	
	/**
	 * Create a TmodelInstance object into UDDI registry.
	 * @param name
	 * @param description
	 * @param url
	 * @return true if creation succeeded 
	 */
	public boolean createTmodelService(String name, String description, String url, String urlDescription) throws JAXRException;
	
	/**
	 * Create a Concept object into UDDI registry.
	 * @param name
	 * @param description
	 * @param url
	 * @return Jaxr Concept Object
	 */
	public Concept createConcept(String name, String description, String url, String urlDescription) throws JAXRException;
	

	

}
