package org.objectweb.petals.tools.juddiAdmin.update;

import javax.xml.registry.BusinessLifeCycleManager;
import javax.xml.registry.BusinessQueryManager;

import org.objectweb.petals.tools.juddiAdmin.Object.Contact;
import org.objectweb.petals.tools.juddiAdmin.connection.ConnectRegistry;




import java.util.ArrayList;
import java.util.Collection;

import javax.xml.registry.BulkResponse;
import javax.xml.registry.JAXRException;
import javax.xml.registry.JAXRResponse;
import javax.xml.registry.infomodel.Classification;
import javax.xml.registry.infomodel.ClassificationScheme;
import javax.xml.registry.infomodel.Concept;
import javax.xml.registry.infomodel.EmailAddress;
import javax.xml.registry.infomodel.ExternalLink;
import javax.xml.registry.infomodel.Organization;
import javax.xml.registry.infomodel.PersonName;
import javax.xml.registry.infomodel.PostalAddress;
import javax.xml.registry.infomodel.Service;
import javax.xml.registry.infomodel.ServiceBinding;
import javax.xml.registry.infomodel.SpecificationLink;
import javax.xml.registry.infomodel.TelephoneNumber;
import javax.xml.registry.infomodel.User;

/**
 * This class allows you to create the flowing UDDI registry objects: 
 * BusinessService, BusinessEntity, BindingTemplate and TmodelInstance. 
 * @author EL JAI Mohammed
 *
 */

public class UpdateRegistryImpl implements UpdateRegistry {
	
	
	/** connection attribute */
	private ConnectRegistry connection;
	
	/**
	 * Just initialize the connection attribute
	 * @param realPath the real path of the root directory
	 */
	public UpdateRegistryImpl(String realPath) {
		connection = ConnectRegistry.getConnection(realPath);
	}

	/*
	 * (non-Javadoc)
	 * @see org.objectweb.petals.tools.juddiAdmin.update.UpdateRegistry#createBusinessEntity(java.lang.String, java.lang.String, org.objectweb.petals.tools.juddiAdmin.Object.Contact)
	 */
	@SuppressWarnings("unchecked")
	public boolean createBusinessEntity(String name, String description, Contact contact) throws JAXRException {
		Collection orgs = new ArrayList();
		BusinessLifeCycleManager blm = connection.getBlm();
		// create organisation
		Organization org = blm.createOrganization(blm.createInternationalString(name));		
		org.setDescription(blm.createInternationalString(description));
		// create contact 
		User user = blm.createUser();
		PersonName personName = blm.createPersonName(contact.getName());
		// create contact phone
		TelephoneNumber telephoneNumber = blm.createTelephoneNumber();
		telephoneNumber.setNumber(contact.getPhone());
		// create contact postal address			
		PostalAddress address = blm.createPostalAddress(contact.getAdresse(),null,null,null,null,null,null); 		 
		Collection postalAddresses = new ArrayList();
		postalAddresses.add(address);
		// create contact email adress 
		Collection emailAddresses = new ArrayList();
		EmailAddress emailAddress = blm.createEmailAddress(contact.getEmail());
		emailAddresses.add(emailAddress);
		// create contact phone number
		Collection numbers = new ArrayList();
		numbers.add(telephoneNumber);
		
		user.setPersonName(personName);                
		user.setPostalAddresses(postalAddresses);
		user.setEmailAddresses(emailAddresses);
		user.setTelephoneNumbers(numbers);
		org.setPrimaryContact(user);
		orgs.add(org);
		// save organization 
		BulkResponse br = blm.saveOrganizations(orgs);
		
		if (br.getStatus() == JAXRResponse.STATUS_SUCCESS) {
			System.out.println("Organization Saved : " + org.getName().getValue());
			return true;
		} else {
			connection.handleJAXRExceptions(br);
			return false;
		}
	} 
		
	

	/*
	 * (non-Javadoc)
	 * @see org.objectweb.petals.tools.juddiAdmin.update.UpdateRegistry#createBusinessService(java.lang.String, java.lang.String, java.lang.String)
	 */
	@SuppressWarnings("unchecked")
	public boolean createBusinessService(String name, String description, Organization org ) throws JAXRException {
		BusinessLifeCycleManager blm = connection.getBlm();
		// create service
		Service service = blm.createService(blm.createInternationalString(name));
		service.setDescription(blm.createInternationalString(description));
		// bind service to organization
		service.setProvidingOrganization(org);
		// save service
		Collection services = new ArrayList();
		services.add(service);
		BulkResponse br = blm.saveServices(services);
		if (br.getStatus() == JAXRResponse.STATUS_SUCCESS) {
			System.out.println("Service Saved : " + service.getName().getValue());
			return true;
		} else {
			connection.handleJAXRExceptions(br);
			return false;
		}
	}
	
	
	/*
	 * (non-Javadoc)
	 * @see org.objectweb.petals.tools.juddiAdmin.update.UpdateRegistry#createBindingTemplate(java.lang.String, java.lang.String, java.lang.String)
	 */
	@SuppressWarnings("unchecked")
	public boolean createBindingTemplate(String name, String description, String acessURI, Concept wsdlConcept, Service service) throws JAXRException {
		BusinessLifeCycleManager blm = connection.getBlm();
		// create service binding
		ServiceBinding sb = blm.createServiceBinding();
		sb.setName(blm.createInternationalString(name));
		sb.setDescription(blm.createInternationalString(description));
		sb.setAccessURI(acessURI);
		SpecificationLink sl = blm.createSpecificationLink();
		sl.setSpecificationObject(wsdlConcept);
		sb.addSpecificationLink(sl);
		// add service binding to BusinessService
		service.addServiceBinding(sb);
		Collection sbs = new ArrayList();
		sbs.add(service);
		BulkResponse br = blm.saveServices(sbs);
		if (br.getStatus() == JAXRResponse.STATUS_SUCCESS) {
			System.out.println("ServiceBinding Saved : " + sb.getName().getValue());
			return true;
		} else {
			connection.handleJAXRExceptions(br);
			return false;
		}
	}

	/*
	 * (non-Javadoc)
	 * @see org.objectweb.petals.tools.juddiAdmin.update.UpdateRegistry#createTmodelService(java.lang.String, java.lang.String, java.lang.String, java.lang.String)
	 */
	@SuppressWarnings("unchecked")
	public boolean createTmodelService(String name, String description, String url, String urlDescription) throws JAXRException {
		BusinessQueryManager bqm = connection.getBqm();
		BusinessLifeCycleManager blm = connection.getBlm();
		Concept wsdlConcept = blm.createConcept(null,name,description);
	    ClassificationScheme scheme =bqm.findClassificationSchemeByName(null,"uddi-org:types");
	    Classification wsdlSpecClassification = blm.createClassification(scheme, blm.createInternationalString("types"), "wsdlSpec");
	    ExternalLink wsdlLink = blm.createExternalLink(name, description);
	    Collection classifications = new ArrayList();
	    classifications.add(wsdlSpecClassification);
	    wsdlConcept.addClassifications(classifications);
	    wsdlConcept.addExternalLink(wsdlLink);
	    Collection coll = new ArrayList();
	    coll.add(wsdlConcept);
	    BulkResponse br = blm.saveConcepts(coll);
		if (br.getStatus() == JAXRResponse.STATUS_SUCCESS) {
			return true;
		} else {
			connection.handleJAXRExceptions(br);
			return false;
		}
	}
	
	/*
	 * (non-Javadoc)
	 * @see org.objectweb.petals.tools.juddiAdmin.update.UpdateRegistry#createTmodelService(java.lang.String, java.lang.String, java.lang.String, java.lang.String)
	 */
	@SuppressWarnings("unchecked")
	public Concept createConcept(String name, String description, String url, String urlDescription) throws JAXRException {
		BusinessQueryManager bqm = connection.getBqm();
		BusinessLifeCycleManager blm = connection.getBlm();
		Concept wsdlConcept = blm.createConcept(null,name,description);
	    ClassificationScheme scheme =bqm.findClassificationSchemeByName(null,"uddi-org:types");
	    Classification wsdlSpecClassification = blm.createClassification(scheme, blm.createInternationalString("types"), "wsdlSpec");
	    ExternalLink wsdlLink = blm.createExternalLink(name, description);
	    Collection classifications = new ArrayList();
	    classifications.add(wsdlSpecClassification);
	    wsdlConcept.addClassifications(classifications);
	    wsdlConcept.addExternalLink(wsdlLink);
	    Collection coll = new ArrayList();
	    coll.add(wsdlConcept);
	    BulkResponse br = blm.saveConcepts(coll);
		if (br.getStatus() == JAXRResponse.STATUS_SUCCESS) {
			return wsdlConcept;
		} else {
			connection.handleJAXRExceptions(br);
			return null;
		}
	}


}
