/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: MessageExchange.java msauvage $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.webadmin.bo;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.ListIterator;
import java.util.Map;

import org.objectweb.petals.tools.webadmin.util.MathTools;
import org.objectweb.petals.tools.webadmin.util.StringHelper;

/**
 * represents an exchange : a list of Message objects
 * 
 * @author msauvage
 * 
 */
public class MessageExchange {
    
    private String exchangeId;
    private long startTime;
    private long endTime;
    private String status;
    private String mep;
    private Map<String,Message> messages;

    /**
     * 
     */
    private static final long serialVersionUID = -6892057539895161917L;

    /**
     * Creates a new MessageExchange with a list of Map
     * 
     * @param exchange
     *            a bulk list representation of an exchange
     */
    public MessageExchange(List<Map<String, Object>> exchange) {
        this.messages = new HashMap<String, Message>();
        ListIterator<Map<String, Object>> parcMsgs = exchange.listIterator();
        // parcourt la liste, crée les objets Message et les ajoute au ME
        long startTime=this.startTime;
        long endTime=this.endTime;
        
        while (parcMsgs.hasNext()) {
            Message msg = new Message(parcMsgs.next());
            messages.put(Long.toString(msg.getTime()),msg);
            
            if (startTime == 0) { startTime=msg.getTime(); }
            else if (msg.getTime() < startTime) {
                startTime=msg.getTime();
            }
            if (endTime == 0) { endTime=msg.getTime(); }
            else if (msg.getTime() > endTime) {
                endTime=msg.getTime();
                if (StringHelper.isNotNullAndNotEmpty(msg.getStatus())) {
                    this.status = msg.getStatus();
                }
            }
            if ((StringHelper.isNullOrEmpty(mep)) && (StringHelper.isNotNullAndNotEmpty(msg.getType()))) {
                this.mep=msg.getType();
            }
        }
        Message endMsg = this.messages.get(Long.toString(this.endTime));
        
        this.exchangeId = endMsg.getId();
   }

    public MessageExchange(Message msg) {
        this.messages = new HashMap<String, Message>();
        this.messages.put(Long.toString(msg.getTime()),msg);
        this.startTime=msg.getTime();
        this.endTime=msg.getTime();
        this.mep=msg.getType();
        this.status = msg.getStatus();
        this.exchangeId = msg.getId();
    }

    /**
     * Get messages from the exchange with timestamp corresponding to the second
     * of a given timestamp
     * 
     * @param timestamp
     *            timestamp of the second wanted
     * @return List of Message objects
     */
    public List<Message> getByTime(long timestamp) {
        List<Message> messages = new ArrayList<Message>();
        for (Message currentMsg : this.messages.values()) {
            if ((currentMsg.getTime() / MathTools.THOUSAND) 
                    == (timestamp / MathTools.THOUSAND)) {
                messages.add(currentMsg);
            }
        }
        return messages;
    }

    /**
     * Returns the id of the Exchange. Search the id in the first message
     * contained by the Exchange.
     * 
     * @return an id, null if exchange has no message.
     */
    public String getExchangeId() {
        String result=null;
        if (StringHelper.isNotNullAndNotEmpty(this.exchangeId)) {
            result=this.exchangeId;
        }
        else if ((this.messages != null) && (!(this.messages.isEmpty())) && (this.messages.get(0) != null)) {
            result= this.messages.get(0).getId();
        }
        return result;
    }

    /**
     * Returns the number of messages in the exchange concerning a component
     * 
     * @param compoName
     *            the name of the component
     * @return a number of messages as a long
     */
    public long getNbMsgByComponent(String compoName) {
        long nbMsg = 0;
        for (Message message : this.messages.values()) {
            if (message.getComponent().equalsIgnoreCase(compoName)) {
                nbMsg++;
            }
        }
        return nbMsg;
    }

    /**
     * Indicates if the MessageExchange has messages concerning a component
     * 
     * @param compoName
     *            the component searched name
     * @return true if MessageExchanges contains messages for the component,
     *         false if not.
     */
    public boolean hasMsgForComponent(String compoName) {
        return this.getNbMsgByComponent(compoName) > 0;
    }

    public long getEndTime() {
        return endTime;
    }

    public String getMep() {
        return mep;
    }

    public Map<String, Message> getMessages() {
        return messages;
    }

    public long getStartTime() {
        return startTime;
    }

    public String getStatus() {
        return status;
    }

    public void addmessage(Message msg) {
        messages.put(Long.toString(msg.getTime()),msg);
        if (startTime == 0) { startTime=msg.getTime(); }
        else if (msg.getTime() < startTime) {
            startTime=msg.getTime();
        }
        if (endTime == 0) { endTime=msg.getTime(); }
        else if (msg.getTime() > endTime) {
            endTime=msg.getTime();
            if (StringHelper.isNotNullAndNotEmpty(msg.getStatus())) {
                this.status = msg.getStatus();
            }
        }
        if ((StringHelper.isNullOrEmpty(mep)) && (StringHelper.isNotNullAndNotEmpty(msg.getType()))) {
            this.mep=msg.getType();
        }
    if (this.endTime == msg.getTime()) {
        this.exchangeId = msg.getId();
    }

    }

}
