/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: CollectorThread.java msauvage $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.webadmin.collector;

import java.io.IOException;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

import javax.management.AttributeNotFoundException;
import javax.management.MBeanException;

public class CollectorThread extends Thread {

    private static DataCollector collector;

    private static final int REFRESH_FREQUENCY = 5000;

    // object for dates formating
    private static final DateFormat DATE_FORMATER = 
        new SimpleDateFormat("dd MMM yyyy, HH:mm:ss");

    private String rootPath;

    public CollectorThread(DataCollector contextCollector, String path) {
        collector = contextCollector;
        rootPath = path;
        // Permet de définir le thread comme daemon a l'OS.
        this.setDaemon(true);
    }

    public void run() {
        while (!Thread.currentThread().isInterrupted()) {
            try {
                if (collector != null && collector.isInit()) {
                    //System.out.println("updating servers...");
                    collector.updateServers();
                } else {
                    if (collector == null) {
                        collector = DataCollector.getCollector();
                    }
                    try {
                        collector.init(rootPath);
                    } catch (AttributeNotFoundException e) {
                        // TODO Auto-generated catch block
                        e.printStackTrace();
                    }
                    this.log("INFO", "Collector Initialized");
                }
            } catch (IOException e) {
                this.log("WARN", e.getMessage());
            } catch (MBeanException e) {
                this.log("ERROR", e.getMessage());
            }
            try {
                synchronized (this) {
                    this.wait(REFRESH_FREQUENCY);
                }
            } catch (InterruptedException ie) {
                Thread.currentThread().interrupt();
            }
        }
    }
    
    private void log(String level, String message) {
     /**   System.out.println("[WEBADMIN " + level + "] " 
            + DATE_FORMATER.format(new Date().getTime()) + " : "
            + message);**/
    }
}
