/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: CollectorManager.java msauvage $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.webadmin.cron;

import java.io.IOException;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.objectweb.petals.tools.webadmin.collector.CollectorThread;
import org.objectweb.petals.tools.webadmin.collector.DataCollector;

public final class CollectorManager extends HttpServlet {

    /**
     * 
     */
    private static final long serialVersionUID = 6616831543123182042L;

    private static final String ACTION_PARAMETER = "t";

    private static CollectorThread cronThread;

    public CollectorManager() {
        super();
    }

    public void destroy(ServletConfig servletConfig) throws ServletException {
        cronThread.interrupt();
    }

    public void init(ServletConfig servletConfig) throws ServletException {
        super.init(servletConfig);
        DataCollector collector = DataCollector.getCollector();
        cronThread = new CollectorThread(collector, this.getServletContext()
            .getRealPath(""));
        cronThread.start();
    }

    protected void doGet(HttpServletRequest request,
        HttpServletResponse response) throws ServletException, IOException {
        this.doPost(request, response);

    }

    @SuppressWarnings("unchecked")
    protected void doPost(HttpServletRequest request,
        HttpServletResponse response) throws ServletException, IOException {

        String message = new String();

        if (request.getParameter(ACTION_PARAMETER) != null) {
            if ("start".equalsIgnoreCase(request.getParameter(ACTION_PARAMETER))) {
                if (cronThread == null) {
                    cronThread = new CollectorThread(DataCollector
                        .getCollector(), 
                        this.getServletContext().getRealPath(""));
                    cronThread.start();
                    message += "PEtALS Datas Collector started";
                } else {
                    message += "Unable to start PEtALS Datas Collector : "
                        + "thread is already running";
                }
            } else if ("stop".equalsIgnoreCase(request.getParameter(ACTION_PARAMETER))) {
                if (cronThread != null) {
                    cronThread.interrupt();
                    cronThread = null;
                    message += "PEtALS Datas Collector stopped and unlinked";
                } else {
                    message += "Unable to stop PEtALS Datas Collector : "
                        + "thread is already stopped";
                }
            } else if ("state".equalsIgnoreCase(request.getParameter(ACTION_PARAMETER))) {
                if (cronThread == null) {
                    message += "PEtALS Datas Collector is actually stopped";
                } else {
                    message += "PEtALS Datas Collector is actually running";
                }
            } else {
                message += "Unknown action received <"
                    + request.getParameter(ACTION_PARAMETER) + ">";
            }
        } else {
            message += "No action received for collector management";
        }
        // request.setAttribute("message", message);
        // request.getRequestDispatcher("/collector-manager.jsp").forward(request,
        // response);
        response.sendRedirect(request.getContextPath()
            + "/collector-manager.jsp?message=" + message);
    }
}
