/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: JMXServer.java msauvage $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.webadmin.jmxserver;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.Reader;
import java.rmi.RemoteException;
import java.rmi.registry.LocateRegistry;
import java.rmi.registry.Registry;
import java.util.Set;

import javax.management.MBeanServer;
import javax.management.MBeanServerFactory;
import javax.management.ObjectName;
import javax.management.remote.JMXConnectorServer;
import javax.management.remote.JMXConnectorServerFactory;
import javax.management.remote.JMXServiceURL;

import org.objectweb.petals.tools.webadmin.mbean.StorageAdminService;

public final class JMXServer {

    private static final int DEFAULT_PORT = 7001;

    private static JMXConnectorServer connectorServer;

    private static String domain;

    private static JMXServiceURL jmxUrl;

    private static MBeanServer myJmxServer;

    private JMXServer jmxServer;

    private JMXServer() {
    }

    /**
     * Create and launches a new MBeanServer.
     *
     * N.B. : All System.out will disappear in last version
     *
     * @param args
     *            an array of String parameters
     * @throws Exception
     *             error occured
     */
    @SuppressWarnings("unchecked")
    public static void main(String[] args) throws Exception {
        int jmxPort = readPortNumber();

        createServer(jmxPort);

        createAdminMBean();

        // displaying exposed MBeans
        System.out.println("\n"
            + connectorServer.getMBeanServer().getMBeanCount().toString()
            + " MBeans registered : ");
        Set<ObjectName> mbNames = (Set<ObjectName>) connectorServer
            .getMBeanServer().queryNames(null, null);
        for (ObjectName objName : mbNames) {
            System.out.println(" - " + objName.toString());
        }

        // stop the connector when user press Enter
        waitForEnterPressed("Server Ready...\nPress <enter> to stop server and exit.");
        connectorServer.stop();
    }

    private static void createAdminMBean() throws Exception {
        // create an administration MBean
        ObjectName adminName = new ObjectName(domain
            + ":name=StorageAdmin,type=service");
        StorageAdminService adminServ = new StorageAdminService(myJmxServer);
        myJmxServer.registerMBean(adminServ, adminName);
    }

    private static void createServer(int port) throws Exception {
        startRMIRegistry(port);
        myJmxServer = MBeanServerFactory.newMBeanServer();
        domain = myJmxServer.getDefaultDomain();
        System.out.println("Server created on default domain : " + domain);

        // creating a rmi connector server to receive calls
        jmxUrl = new JMXServiceURL("service:jmx:rmi:///jndi/rmi://localhost:"
            + port + "/management/rmi-jmx-connector");
        connectorServer = JMXConnectorServerFactory.newJMXConnectorServer(
            jmxUrl, null, myJmxServer);
        connectorServer.start();
        System.out.println("RMI Connector address : "
            + connectorServer.getAddress());
    }


    private static Registry startRMIRegistry(int port) throws RemoteException {
        Registry registry = LocateRegistry.createRegistry(port);
        return registry;
    }

    private static int readPortNumber() throws IOException {
        Reader reader = new InputStreamReader(System.in);
        BufferedReader input = new BufferedReader(reader);
        System.out.print("Port number for server ("+DEFAULT_PORT+" default) : ");
        try {
            return new Integer(input.readLine()).intValue();
        } catch (NumberFormatException nfe) {
            return DEFAULT_PORT;
        }
    }

    private static void waitForEnterPressed(String message) {
        try {
            System.out.println(message);
            System.in.read();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public JMXServer getJMXServer() {
        if (jmxServer == null) {
            jmxServer = new JMXServer();
        }
        return jmxServer;
    }
}
