/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: ComponentsList.java msauvage $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.webadmin.mbean;

import java.util.HashMap;
import java.util.Map;

public class ComponentsList implements ComponentsListMBean {

    /**
     * components stored as a <server,components> map where components is a map
     * of <name,component> components, where component is a map of
     * <property,value> items
     */
    private Map<String, Map<String, Map<String, Object>>> components;

    /**
     * Create a new empty set
     * 
     */
    public ComponentsList() {
        components = new HashMap<String, Map<String, Map<String, Object>>>();
    }

    /**
     * Create a new components list
     * 
     * @param components
     */
    public ComponentsList(
        Map<String, Map<String, Map<String, Object>>> components) {
        this.components = components;
    }

    /**
     * Add a set of components for a server. If a set already exists for this
     * server, it's replaced by the new given
     * 
     * @param serverName
     *            a String representation of the server's name
     * @param components
     *            the components of the server
     */
    public void addComponents(String serverName,
        Map<String, Map<String, Object>> componentsMap) {
        this.components.put(serverName, componentsMap);
    }

    /**
     * Gets a component of a server
     * 
     * @param serverName
     *            the server's name
     * @param componentName
     *            the component's name
     * @return a Map representation of the component
     */
    public Map<String, Object> getComponent(String serverName,
        String componentName) {
        return this.components.get(serverName).get(componentName);
    }

    /**
     * Returns all components for all servers
     */
    public Map<String, Map<String, Map<String, Object>>> getComponents() {
        return components;
    }

    /**
     * Gets the components of a server
     * 
     * @param serverName
     *            the name of the server
     * @return a set of components
     */
    public Map<String, Map<String, Object>> getComponents(String serverName) {
        return this.components.get(serverName);
    }

    /**
     * Gets the components of a server from a type
     * 
     * @param serverName
     *            the name of the server
     * @param type
     *            type wanted : BC for Binding Component, SE for Service Engine
     * @return a set of components
     */
    public Map<String, Map<String, Object>> getComponents(String serverName,
        String type) {
        String completeType = new String();
        if (type.equalsIgnoreCase("BC")) {
            completeType = "Binding Component";
        } else if (type.equalsIgnoreCase("SE")) {
            completeType = "Service Engine";
        } else {
            return null;
        }
        Map<String, Map<String, Object>> allComponents = this.components
            .get(serverName);
        Map<String, Map<String, Object>> selection = 
            new HashMap<String, Map<String, Object>>();
        for (String compoName : allComponents.keySet()) {
            if (allComponents.get(compoName).get("type").equals(completeType)) {
                selection.put(compoName, allComponents.get(compoName));
            }
        }
        return selection;
    }

    /**
     * Sets the new components list to store
     * 
     * @param components
     *            the complete map of components
     */
    public void setComponents(
        Map<String, Map<String, Map<String, Object>>> components) {
        this.components = components;
    }

}
