/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: ServersList.java msauvage $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.webadmin.mbean;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

public class ServersList implements ServersListMBean, Serializable {

    /**
     * 
     */
    private static final long serialVersionUID = 7755340123877329173L;

    /**
     * The list of servers
     */
    private List<Map<String, String>> servers;

    /**
     * Creates a new empty ServersList
     * 
     */
    public ServersList() {
    }

    /**
     * Creates a new ServersList and initialize his serversList attribute
     * 
     * @param serversList
     *            the new serversList
     */
    public ServersList(List<Map<String, String>> serversList) {
        this.servers = serversList;
    }

    /**
     * Adds a server configuration to the list
     * 
     * @param serverConf
     *            the server configuration to add
     */
    public void addServer(Map<String, String> serverConf) {
        this.servers.add(serverConf);
    }

    /**
     * Gets the server configuration of the server with given name
     * 
     * @param serverName
     *            the name of the searched server
     * @return a server configuration
     */
    public Map<String, String> getServerConfiguration(String serverName) {
        for (Map<String, String> currentConf : this.servers) {
            if (currentConf.get("name").equalsIgnoreCase(serverName)) {
                return currentConf;
            }
        }
        return null;
    }

    /**
     * Gets the list of servers configurations
     */
    public List<Map<String, String>> getServers() {
        return servers;
    }

    /**
     * Sets a new servers list
     * 
     * @param serversList
     *            the new servers list
     */
    public void setServers(List<Map<String, String>> serversList) {
        this.servers = serversList;
    }

    /**
     * Update a server's configuration in the list. Adds it if the configuration
     * doesn't already exists in the list
     * 
     * @param newServerConf
     *            the new server's configuration of server to update
     */
    public void updateServer(Map<String, String> newServerConf) {
        int serverIndex = indexOfServer(newServerConf.get("name"));
        if (serverIndex >= 0) {
            servers.set(serverIndex, newServerConf);
        } else {
            servers.add(newServerConf);
        }
    }

    /**
     * returns the index in the list of the server with the specified name, or
     * -1 if server is not found
     * 
     * @param serverName
     *            the name of the server
     * @return the index in the list, or -1 if server is not found
     */
    private int indexOfServer(String serverName) {
        int index = 0;
        while (index < servers.size()) {
            if (servers.get(index).get("name").equalsIgnoreCase(serverName)) {
                return index;
            }
            index++;
        }
        return -1;
    }

}
