/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: StorageAdminService.java msauvage $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.webadmin.mbean;

import java.io.IOException;
import java.util.List;
import java.util.Map;

import javax.management.Attribute;
import javax.management.AttributeNotFoundException;
import javax.management.InstanceAlreadyExistsException;
import javax.management.InstanceNotFoundException;
import javax.management.InvalidAttributeValueException;
import javax.management.MBeanException;
import javax.management.MBeanServer;
import javax.management.NotCompliantMBeanException;
import javax.management.ObjectName;
import javax.management.ReflectionException;

public class StorageAdminService implements StorageAdminServiceMBean {

    private final boolean ping = true;

    private MBeanServer jmxServer;

    private ObjectName SERVERS_MBEAN_NAME;

    private ObjectName COMPONENTS_MBEAN_NAME;

    private ObjectName TIMEDATAS_MBEAN_NAME;

    public StorageAdminService(MBeanServer jmxServer) throws IOException {
        this.jmxServer = jmxServer;
    }

    public boolean getPing() {
        return ping;
    }

    /**
     * Initialize a ComponentsList MBean with a name and a set of components.
     * 
     * If MBean is already registered, his "components" attribute is set to new
     * value.
     * 
     * @param mBeanName
     *            the name to associate to the MBean
     * @param serversComponents
     *            the set of components
     * @throws MBeanException
     */
    public boolean initComponentsMBean(ObjectName mBeanName,
        Map<String, Map<String, Map<String, Object>>> serversComponents)
        throws MBeanException {
        try {
            COMPONENTS_MBEAN_NAME = mBeanName;
            if (!jmxServer.isRegistered(COMPONENTS_MBEAN_NAME)) {
                ComponentsList componentsMBean = new ComponentsList(
                    serversComponents);
                jmxServer.registerMBean(componentsMBean, COMPONENTS_MBEAN_NAME);
            } else {
                jmxServer.setAttribute(COMPONENTS_MBEAN_NAME, new Attribute("Components",
                    serversComponents));
            }
            return true;
        } catch (InstanceAlreadyExistsException e) {
            throw new MBeanException(e);
        } catch (InstanceNotFoundException e) {
            throw new MBeanException(e);
        } catch (AttributeNotFoundException e) {
            throw new MBeanException(e);
        } catch (InvalidAttributeValueException e) {
            throw new MBeanException(e);
        } catch (NotCompliantMBeanException e) {
            throw new MBeanException(e);
        } catch (MBeanException e) {
            throw new MBeanException(e);
        } catch (ReflectionException e) {
            throw new MBeanException(e);
        }
    }

    /**
     * Initialize a ServersList MBean, containing connections informations for a
     * set of servers.
     * 
     * If MBean is already registered, the list of servers is initialized to new
     * value
     * 
     * 
     * @param mBeanName
     *            the name to associate with the MBean
     * @param serversList
     *            the new list of connections informations
     * @throws MBeanException
     */
    public boolean initServersMBean(ObjectName mBeanName,
        List<Map<String, String>> serversList) throws MBeanException {
        try {
            SERVERS_MBEAN_NAME = mBeanName;
            if (!jmxServer.isRegistered(SERVERS_MBEAN_NAME)) {
                ServersList serversListMBean = new ServersList(serversList);
                jmxServer.registerMBean(serversListMBean, SERVERS_MBEAN_NAME);
            } else {
                jmxServer.setAttribute(SERVERS_MBEAN_NAME, new Attribute(
                    "Servers", serversList));
            }
            return true;
        } catch (InstanceAlreadyExistsException e) {
            throw new MBeanException(e);
        } catch (NotCompliantMBeanException e) {
            throw new MBeanException(e);
        } catch (InstanceNotFoundException e) {
            throw new MBeanException(e);
        } catch (AttributeNotFoundException e) {
            throw new MBeanException(e);
        } catch (InvalidAttributeValueException e) {
            throw new MBeanException(e);
        } catch (MBeanException e) {
            throw new MBeanException(e);
        } catch (ReflectionException e) {
            throw new MBeanException(e);
        }
    }

    public boolean initTimeDatasMBean(ObjectName mBeanName,
        Map<String, Map<Long, Long>> datasets) throws MBeanException {
        try {
            TIMEDATAS_MBEAN_NAME = mBeanName;
            if (!jmxServer.isRegistered(TIMEDATAS_MBEAN_NAME)) {
                TimeDatas timeDatasMBean = new TimeDatas(datasets);
                jmxServer.registerMBean(timeDatasMBean, TIMEDATAS_MBEAN_NAME);
            } else {
                jmxServer.setAttribute(TIMEDATAS_MBEAN_NAME, new Attribute("Datas", datasets));
            }
            return true;
        } catch (InstanceAlreadyExistsException e) {
            throw new MBeanException(e);
        } catch (NotCompliantMBeanException e) {
            throw new MBeanException(e);
        } catch (InstanceNotFoundException e) {
            throw new MBeanException(e);
        } catch (AttributeNotFoundException e) {
            throw new MBeanException(e);
        } catch (InvalidAttributeValueException e) {
            throw new MBeanException(e);
        } catch (MBeanException e) {
            throw new MBeanException(e);
        } catch (ReflectionException e) {
            throw new MBeanException(e);
        }
    }

}
