/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: TimeDatas.java msauvage $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.webadmin.mbean;

import java.util.HashMap;
import java.util.Map;

public class TimeDatas implements TimeDatasMBean {

    /**
     * datas stored in the MBean
     */
    private Map<String, Map<Long, Long>> datas;

    /**
     * Creates a new empty TimeDatas
     * 
     */
    public TimeDatas() {
        datas = new HashMap<String, Map<Long, Long>>();
    }

    /**
     * Creates a new TimeDatas with datas given
     * 
     * @param datas
     *            a Map of datas to store
     */
    public TimeDatas(Map<String, Map<Long, Long>> datas) {
        this.datas = datas;
    }

    /**
     * Adds the given pair of values to a dataset stored.
     * 
     * @param datasetName
     *            name of the dataset in which to add the datas
     * @param timestamp
     *            a timestamp, used as the key with which the specified
     *            <i>number</i> value is to be associated.
     * @param number
     *            value to be associated with the specified <i>timestamp</i>.
     * @return 0 if pair is correctly added, 1 if an exception occures
     */
    public int add(String datasetName, long timestamp, long number) {
        datas.get(datasetName).put(timestamp, number);
        return 0;
    }

    /**
     * Add all values of a given datas to a dataset
     * 
     * @param newDatas
     *            datas to be stored
     * @return 0 if datas are correctly added, 1 if an Exception occures
     */
    public int addAll(String datasetName, Map<Long, Long> newDatas) {
        Map<Long, Long> dataset;
        // retrieve existing dataset or create it
        if (datas.get(datasetName) != null) {
            dataset = datas.get(datasetName);
        } else {
            dataset = new HashMap<Long, Long>();
            datas.put(datasetName, dataset);
        }
        for (Long timestamp : newDatas.keySet()) {
            // creating entry if timestamp doesn't already exists in
            // datas stored
            // else adding count to count stored
            if (dataset.get(timestamp) == null) {
                dataset.put(timestamp, newDatas.get(timestamp));
            } else {
                dataset.put(timestamp, newDatas.get(timestamp)
                    + dataset.get(timestamp));
            }
        }
        return 0;
    }

    /**
     * Sets a new dataset to store. If dataset with a same name already exists,
     * it's replaced with new datas
     * 
     * @param datasetName
     *            name to use for key of the dataset
     * @param datas
     *            Map of datas to store
     */
    public void addDataset(String datasetName, Map<Long, Long> newDatas) {
        this.datas.put(datasetName, newDatas);
    }

    /**
     * Remove all datas stored
     * 
     * @return 0 if datas are correctly erased, 1 if an exception occures
     */
    public int clear() {
        datas.clear();
        return 0;
    }

    /**
     * Returns the datas, as a Map.
     * 
     * @return a Map<Long,Long> of datas stored
     */
    public Map<String, Map<Long, Long>> getDatas() {
        return datas;
    }

    /**
     * gets the datas of a dataset from a given time
     * 
     * @param datasetName
     *            the name of the dataset
     * @param sinceTime
     *            time of search begin
     * @return a Map representation of the datas, null if dataset is not found
     */
    public Map<Long, Long> getDatas(String datasetName, long sinceTime) {
        Map<Long, Long> datasSelection = new HashMap<Long, Long>();
        if (datas.get(datasetName) != null) {
            Map<Long, Long> dataset = datas.get(datasetName);
            // selecting datas with timestamp after asked time
            for (long timestamp : dataset.keySet()) {
                if (timestamp >= sinceTime) {
                    datasSelection.put(timestamp, dataset.get(timestamp));
                }
            }
            return datasSelection;
        } else {
            return null;
        }
    }

    public Map<Long, Long> getDataset(String datasetName) {
        return datas.get(datasetName);
    }

    /**
     * Sets datas to a new Map of datasets
     * 
     * @param datas
     *            Map containing datasets with their name as keys
     */
    public void setDatas(Map<String, Map<Long, Long>> datas) {
        this.datas = datas;
    }

}
