/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.tools.webadmin.ui.administration;

import javax.management.MBeanException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.petals.tools.webadmin.collector.DataCollector;
import org.objectweb.petals.tools.webadmin.ui.infra.action.AuthentifiedAction;
import org.objectweb.petals.tools.webadmin.ui.infra.bean.InfoBean;
import org.objectweb.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.objectweb.petals.tools.webadmin.util.StringHelper;

/**
 * used to change bc or se' state
 * 
 * request params : server, component, action
 * 
 * @author mcarpentier - EBM Websourcing
 *
 */
public class ChangeComponentState extends AuthentifiedAction {

    @Override
    public ActionForward executeAuthentified(ActionMapping iActionMapping,
            ActionForm iActionForm, HttpServletRequest iServletRequest,
            HttpServletResponse iServletResponse) throws Exception {

        String server = iServletRequest.getParameter("server");
        String component = iServletRequest.getParameter("component");
        String action = iServletRequest.getParameter("action");
        AdminSession adminSession = AdminSession.getAdminSession(iServletRequest.getSession());
        
        /** set navigation info**/
        adminSession.setSelectedMenu(AdminSession.PETALS_ADMINISTRATION);

        iServletRequest.setAttribute("server", server);

        /** deals with error messages **/
        InfoBean infoBean = new InfoBean();
        if (StringHelper.isNullOrEmpty(server)
                || (StringHelper.isNullOrEmpty(component))
                || ((StringHelper.isNullOrEmpty(action)))) {
            infoBean
                    .setMessage("Error: can't change component's state : missing parameter");
            infoBean.setMessageType(InfoBean.ERROR_MESSAGE);
            adminSession.setInfobean(infoBean);
            
        }
        try {
            DataCollector collector = DataCollector.getCollector();
            collector.changeCompoState(server, component, action);
            // force to refresh datas on storage server before refreshing
            // display via js
            collector.updateAndExposeComponents();
            infoBean.setMessage("State of " + component
                    + " successfully changed ");
            infoBean.setMessageType(InfoBean.INFO_MESSAGE);
            adminSession.setInfobean(infoBean);
        } catch (MBeanException e) {
            infoBean.setMessage("Error: can't change component's state : "
                    + e.getMessage());
            infoBean.setMessageType(InfoBean.ERROR_MESSAGE);
            adminSession.setInfobean(infoBean);
        }
        return iActionMapping.findForward("success");
    }

}
