/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.tools.webadmin.ui.administration;

import java.io.File;
import java.io.FileOutputStream;
import java.util.Date;

import javax.management.MBeanException;
import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.upload.FormFile;
import org.apache.struts.validator.DynaValidatorForm;
import org.objectweb.petals.tools.webadmin.collector.DataCollector;
import org.objectweb.petals.tools.webadmin.ui.infra.action.AuthentifiedAction;
import org.objectweb.petals.tools.webadmin.ui.infra.bean.InfoBean;
import org.objectweb.petals.tools.webadmin.ui.infra.session.AdminSession;
/**
 * Upload a component to a temporary directory and install it
 * 
 * request params : componentFile, server
 * 
 * @author mcarpentier - EBM Websourcing
 *
 */
public class InstallComponent extends AuthentifiedAction {

    @Override
    public ActionForward executeAuthentified(ActionMapping iActionMapping,
            ActionForm iActionForm, HttpServletRequest iServletRequest,
            HttpServletResponse iServletResponse) throws Exception {

        DynaValidatorForm form = (DynaValidatorForm) iActionForm;
        AdminSession adminSession = AdminSession.getAdminSession(iServletRequest.getSession());
        
        /** set navigation info**/
        adminSession.setSelectedMenu(AdminSession.PETALS_ADMINISTRATION);
        
        FormFile componentFile = (FormFile) form.get("componentFile");
        String serverName = (String) form.get("server");
        iServletRequest.setAttribute("server", serverName);
        
        InfoBean infoBean = new InfoBean();
        byte[] wavdatas = componentFile.getFileData();
        ServletContext context = iServletRequest.getSession()
                .getServletContext();

        String reqPath = iServletRequest.getContextPath();
        reqPath = reqPath.substring(reqPath.lastIndexOf("/") + 1);
        String realContextPath = context.getRealPath(iServletRequest
                .getContextPath());
        String rootPath = realContextPath.substring(0, realContextPath
                .lastIndexOf(reqPath));
        File uploadDir = new File(rootPath + "upload/");
        if (!(uploadDir.exists())) {
            
            if (!(uploadDir.mkdir())) {
                infoBean.setMessage("Error: can't create upload directory");
                infoBean.setMessageType(InfoBean.ERROR_MESSAGE);
                adminSession.setInfobean(infoBean);
                return iActionMapping.findForward("success");
            }
            
        }
        
        String tmpDir = String.valueOf(new Date().getTime());
        uploadDir = new File(rootPath + "upload/" + tmpDir);
        if (!(uploadDir.exists())) {
            if (!(uploadDir.mkdir())) {
                infoBean.setMessage("Error: can't create upload directory");
                infoBean.setMessageType(InfoBean.ERROR_MESSAGE);
                adminSession.setInfobean(infoBean);
               return iActionMapping.findForward("success");
            }
        }

        String filePath = uploadDir.getAbsolutePath() + File.separator + componentFile.getFileName();
        
        FileOutputStream fos = new FileOutputStream(new File(filePath));
        fos.write(wavdatas);
        fos.close();
        componentFile.destroy();

        if (serverName != null) {
            DataCollector collector = DataCollector.getCollector();
            try {
                // constructs http url of file uploaded
                String jspUrl = iServletRequest.getRequestURL().toString();
                int lastSeparator = jspUrl.lastIndexOf("/") + 1;
                String httpUrl = jspUrl.substring(0, lastSeparator) + "upload/"
                        + tmpDir + "/" +componentFile.getFileName();
                collector.installComponent(serverName, httpUrl);
                
                // force to refresh datas on storage server before refreshing
                // display via js
                collector.updateAndExposeComponents();
            } catch (MBeanException e) {
                if (!(uploadDir.mkdir())) {
                    infoBean.setMessage("Error: can't install component : "+ e.getMessage());
                    infoBean.setMessageType(InfoBean.ERROR_MESSAGE);
                    adminSession.setInfobean(infoBean);
                    e.printStackTrace();
                    return iActionMapping.findForward("success");
                }
            }
        }
        
        /** deals with info messages **/
        infoBean.setMessage("Component successfully installed");
        infoBean.setMessageType(InfoBean.INFO_MESSAGE);
        adminSession.setInfobean(infoBean);
        
        

        return iActionMapping.findForward("success");

        
    }
}
