/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.tools.webadmin.ui.logon;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.Action;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;
import org.apache.struts.action.DynaActionForm;
import org.objectweb.petals.tools.webadmin.bo.ServerConfiguration;
import org.objectweb.petals.tools.webadmin.collector.DataCollector;
import org.objectweb.petals.tools.webadmin.service.NewJMXService;
import org.objectweb.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.objectweb.petals.tools.webadmin.ui.infra.session.WebUser;
import org.objectweb.petals.tools.webadmin.util.JMXUtils;
import org.objectweb.petals.tools.webadmin.util.ServerPropertiesManager;

/**
 * Triggered when an user logs in
 * 
 * @author mcarpentier
 * 
 */
public class Logon extends Action {
    @Override
    public ActionForward execute(ActionMapping iActionMapping, ActionForm form,
            HttpServletRequest iRequest, HttpServletResponse iResponse)
            throws Exception {

        DynaActionForm logonForm = (DynaActionForm) form;

        String jmxLogin = (String) logonForm.get("login");
        String jmxPort = (String) logonForm.get("port");
        String serverHost = (String) logonForm.get("host");
        String jmxPassword = (String) logonForm.get("password");
        String nextUrl = (String) logonForm.get("nextUrl");

        boolean serverReachable = false;

        AdminSession adminSession = AdminSession.getAdminSession(iRequest
                .getSession());
        WebUser webUser = null;

        // webUser = WebUser.login(login,password);
        webUser = new WebUser();
        ServerConfiguration entryServerConf = new ServerConfiguration(
                serverHost, jmxPort, jmxLogin, jmxPassword);
        try {
            entryServerConf.createConnection();
        } catch (IOException e) {
            e.printStackTrace();
            // do nothing : connection and server tested below
        }
        serverReachable = JMXUtils.getJMXUtils().petalsServerReachable(
                entryServerConf);
        if (serverReachable) // server asked is accessible
        {
            // creates a server properties manager pointing to properties file
            ServerPropertiesManager propMgr = new ServerPropertiesManager(
                    iRequest.getSession().getServletContext().getRealPath(""));
            propMgr.load();

            // server is active -> retrieve and set connection to it
            entryServerConf.createConnection();
            // retrieves name of the PEtALS server via JMX call to it
            entryServerConf.setName();
            // sets entry server configuration in session
            adminSession.setEntryServerConf(entryServerConf);
            // sets server s info in properties
            propMgr.setAttribute("serverHost", serverHost);
            propMgr.setAttribute("jmxPort", jmxPort);
            propMgr.setAttribute("jmxLogin", jmxLogin);
            propMgr.setAttribute("jmxPassword", jmxPassword);

            String storageServerHost = propMgr
                    .getAttributeValue("storageServerHost");
            String storageJmxPort = propMgr.getAttributeValue("storageJmxPort");
            String storageJmxLogin = propMgr
                    .getAttributeValue("storageJmxLogin");
            String storageJmxPassword = propMgr
                    .getAttributeValue("storageJmxPassword");

            // creates a server configuration for the storage server and
            // registers it in session
            ServerConfiguration storageServerConf = new ServerConfiguration(
                    "JMXDatas", storageServerHost, storageJmxPort,
                    storageJmxLogin, storageJmxPassword);
            adminSession.setStorageServerConf(storageServerConf);

            // saves properties in file
            propMgr.save();

            // gets the datacollector initialized by thread
            DataCollector collector = DataCollector.getCollector();
            // sets the entry server to the server given by user
            collector.setEntryServerConf(entryServerConf);
            collector.updateServers();

            // initializes the singleton for jmx service with storage server
            NewJMXService.createNewJmxService(storageServerConf);

            // forwards user to application

            adminSession.setUser(webUser);

            if ((nextUrl == null) || (nextUrl.length() == 0)) {
                return iActionMapping.findForward("success");
            }

            return new ActionForward(nextUrl, true);
        } else {
            // displays information
            ActionMessages am = new ActionMessages();
            am.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage(
                    "logon.jmx.failure"));
            saveErrors(iRequest, am);
            return iActionMapping.findForward("failure");
        }

    }
}
