/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.webadmin.ui.monitoring;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.DynaActionForm;
import org.objectweb.petals.tools.webadmin.bo.Message;
import org.objectweb.petals.tools.webadmin.bo.MessageExchange;
import org.objectweb.petals.tools.webadmin.collector.DataCollector;
import org.objectweb.petals.tools.webadmin.ui.infra.action.AuthentifiedAction;
import org.objectweb.petals.tools.webadmin.ui.infra.bean.MessageLVO;
import org.objectweb.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.objectweb.petals.tools.webadmin.ui.infra.util.MessageTimeComparator;
import org.objectweb.petals.tools.webadmin.util.DateHelper;
import org.objectweb.petals.tools.webadmin.util.StringHelper;
/**
 * @author mcarpentier  - EBM Websourcing
 */
public class ShowExchangeDetails extends AuthentifiedAction {

    @Override
    public ActionForward executeAuthentified(ActionMapping iActionMapping,
            ActionForm iActionForm, HttpServletRequest iServletRequest,
            HttpServletResponse iServletResponse) throws Exception {
        AdminSession adminSession = AdminSession
                .getAdminSession(iServletRequest.getSession());

        /** set navigation info* */
        adminSession.setSelectedMenu(AdminSession.MONITORING);

        DynaActionForm form = (DynaActionForm) iActionForm;

        String exchangeId = iServletRequest.getParameter("exchangeId");
        String serverName = iServletRequest.getParameter("server");
        String message = iServletRequest.getParameter("messageId");
        String currentMessage = iServletRequest.getParameter("currentMessage");
        
        if (StringHelper.isNullOrEmpty(currentMessage)) {
            currentMessage="0";
        }

        form.set("serverName", serverName);
        DataCollector collector = DataCollector.getCollector();

        MessageExchange ex = collector.getMessageExchange(serverName,
                exchangeId);
        if (ex != null) {

            Date end = new Date(ex.getEndTime());
            Date start = new Date(ex.getStartTime());

            form.set("endTime", DateHelper.format(end));
            form.set("startTime", DateHelper.format(start));
            form.set("mep", ex.getMep());
            form.set("exchangeId", exchangeId);
            form.set("status", ex.getStatus());
            form.set("currentMessage", currentMessage);

            List<String> messages = new ArrayList<String>();
            if (ex.getMessages() != null) {
                for (Message msg : ex.getMessages().values()) {
                    MessageLVO mLVO = new MessageLVO();
                    messages.add(Long.toString(msg.getTime()));
                }
                Collections.sort(messages, new MessageTimeComparator());

                if (StringHelper.isNullOrEmpty(message)) {
                    message = messages.get(0);
                }
                Message msg = ex.getMessages().get(message);
                MessageLVO mLVO = new MessageLVO();
                mLVO.setComponent(msg.getComponent());
                String toDisplay = msg.getContent();
                if (StringHelper.isNotNullAndNotEmpty(toDisplay)) {
                    toDisplay=StringHelper.prettyPrint(toDisplay);
                    toDisplay=StringHelper.HTMLEntityEncode(toDisplay);
                }
                mLVO.setContent(toDisplay);
                mLVO.setEndpointname(msg.getEndpointName());
                mLVO.setMessageId(msg.getId());
                mLVO.setServiceName(msg.getServiceName());
                mLVO.setStatus(msg.getStatus());
                Date msgTime = new Date(msg.getTime());
                mLVO.setTime(DateHelper.format(msgTime,DateHelper.DETAILLED_DATEFORMAT));
                form.set("message", mLVO);

            }

            form.set("messages", messages);
        }

        return iActionMapping.findForward("success");
    }

}
