/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.tools.webadmin.ui.monitoring;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.DynaActionForm;
import org.objectweb.petals.tools.webadmin.bo.Message;
import org.objectweb.petals.tools.webadmin.bo.MessageExchange;
import org.objectweb.petals.tools.webadmin.collector.DataCollector;
import org.objectweb.petals.tools.webadmin.ui.infra.action.AuthentifiedAction;
import org.objectweb.petals.tools.webadmin.ui.infra.bean.ExchangeLVO;
import org.objectweb.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.objectweb.petals.tools.webadmin.ui.infra.util.ExchangeLVOComparator;
import org.objectweb.petals.tools.webadmin.ui.infra.util.MessageTimeComparator;
import org.objectweb.petals.tools.webadmin.util.DateHelper;
import org.objectweb.petals.tools.webadmin.util.StringHelper;

/**
 * @author mcarpentier - EBM Websourcing
 */
public class ShowExchanges extends AuthentifiedAction {
    public static String MESSAGES_PER_PAGE="10";
    
    @Override
    public ActionForward executeAuthentified(ActionMapping iActionMapping,
            ActionForm iActionForm, HttpServletRequest iServletRequest,
            HttpServletResponse iServletResponse) throws Exception {

        AdminSession adminSession = AdminSession
                .getAdminSession(iServletRequest.getSession());

        /** set navigation info* */
        adminSession.setSelectedMenu(AdminSession.MONITORING);

        DynaActionForm form = (DynaActionForm) iActionForm;

        DataCollector collector = DataCollector.getCollector();

        String serverName = iServletRequest.getParameter("server");
        String startMessage = iServletRequest.getParameter("startMessage");
        String messagesPerPage = iServletRequest
                .getParameter("messagesPerPage");

        if (StringHelper.isNullOrEmpty(startMessage)) {
            startMessage = "0";
        }
        if (StringHelper.isNullOrEmpty(messagesPerPage)) {
            messagesPerPage = MESSAGES_PER_PAGE;
        }

        form.set("serverName", serverName);

        Map<String, MessageExchange> exchanges = collector
                .getMessagesExchanges(serverName);
        if (exchanges != null) {

            List<ExchangeLVO> exchangesList = new ArrayList<ExchangeLVO>();

            for (MessageExchange ex : exchanges.values()) {
                ExchangeLVO exLVO = new ExchangeLVO();

                Date end = new Date(ex.getEndTime());
                Date start = new Date(ex.getStartTime());

                exLVO.setEndTime(DateHelper.format(end));
                exLVO.setStartTime(DateHelper.format(start));
                exLVO.setMep(ex.getMep());
                exLVO.setExchangeId(ex.getExchangeId());
                exLVO.setStatus(ex.getStatus());
                List<String> messages = new ArrayList<String>();
                if (ex.getMessages() != null) {
                    for (Message msg : ex.getMessages().values()) {
                        messages.add(Long.toString(msg.getTime()));
                        exLVO.addInvolvedComponent(msg.getComponent());
                    }
                }

                Collections.sort(messages, new MessageTimeComparator());
                exchangesList.add(exLVO);

            }
            Collections.sort(exchangesList, new ExchangeLVOComparator());

            /** apply filter on sorted list* */
            List<ExchangeLVO> result = new ArrayList<ExchangeLVO>();

            int currentMsg = Integer.parseInt(startMessage);
            int finalMsg = Integer.parseInt(messagesPerPage) + currentMsg - 1;
            
            for (int i = currentMsg; (i <= finalMsg && (i < exchangesList.size())); i++) {
                result.add(exchangesList.get(i));
            }

            form.set("startMessage", startMessage);
            form.set("messagesPerPage", messagesPerPage);
            form.set("totalMessages", String.valueOf(exchangesList.size()));

            form.set("exchanges", result);

        }

        return iActionMapping.findForward("success");
    }

}
