/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.tools.webadmin.ui.monitoring;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;
import org.apache.struts.action.DynaActionForm;
import org.objectweb.petals.tools.webadmin.bo.ServerConfiguration;
import org.objectweb.petals.tools.webadmin.service.NewJMXService;
import org.objectweb.petals.tools.webadmin.ui.infra.action.AuthentifiedAction;
import org.objectweb.petals.tools.webadmin.ui.infra.bean.ComponentLVO;
import org.objectweb.petals.tools.webadmin.ui.infra.bean.ServerLVO;
import org.objectweb.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.objectweb.petals.tools.webadmin.util.JBIEntity;
/**
 * @author mcarpentier  - EBM Websourcing
 */
public class ShowMenu extends AuthentifiedAction {

    @Override
    public ActionForward executeAuthentified(ActionMapping iActionMapping,
            ActionForm iActionForm, HttpServletRequest iServletRequest,
            HttpServletResponse iServletResponse) throws Exception {

        AdminSession adminSession = AdminSession.getAdminSession(iServletRequest.getSession());
        
        /** set navigation info**/
        adminSession.setSelectedMenu(AdminSession.MONITORING);

        List<ServerLVO> servers = new ArrayList<ServerLVO>();
        try {
            NewJMXService jmxService = NewJMXService.getJmxService();
            //retrieve servers
            List<ServerConfiguration> serversList = jmxService
                    .getStartedServersList();
            for (ServerConfiguration currentServer : serversList) {
                
                String serverName = currentServer.getName();
                ServerLVO server = new ServerLVO(serverName);
                
                //retrieve server's components
                Map<String, JBIEntity> serverComponents = jmxService
                        .getComponents(serverName);
                if (serverComponents != null) {
                    for (String s : serverComponents.keySet()) {
                        JBIEntity component = serverComponents.get(s);
                        ComponentLVO componentLVO = new ComponentLVO(component
                                .getName(), component.getState());
                        componentLVO.setType(component.getType());
                        server.addComponent(componentLVO);
                    }
                }
                
                servers.add(server);
            }

            DynaActionForm form = (DynaActionForm) iActionForm;
            form.set("servers", servers);

        } catch (Exception e) {
            ActionMessages am = new ActionMessages();
            am.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage(
                    "webconsole.exception", e.getMessage()));
            saveErrors(iServletRequest, am);
            return iActionMapping.findForward("failure");
        }
        return iActionMapping.findForward("success");

    }

}
