/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.webadmin.ui.monitoring;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.management.ObjectName;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.DynaActionForm;
import org.objectweb.petals.kernel.admin.PetalsAdminServiceMBean;
import org.objectweb.petals.tools.webadmin.service.NewJMXService;
import org.objectweb.petals.tools.webadmin.ui.infra.action.AuthentifiedAction;
import org.objectweb.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.objectweb.petals.tools.webadmin.ui.monitoring.beans.ComponentBean;
import org.objectweb.petals.tools.webadmin.ui.monitoring.beans.ServerBean;
/**
 * @author mcarpentier  - EBM Websourcing
 */
public class ShowNetwork extends AuthentifiedAction {
    @Override
    public ActionForward executeAuthentified(ActionMapping iActionMapping,
        ActionForm iActionForm, HttpServletRequest iServletRequest,
        HttpServletResponse iServletResponse) throws Exception {

        AdminSession adminSession = AdminSession.getAdminSession(iServletRequest.getSession());
        
        /** set navigation info**/
        adminSession.setSelectedMenu(AdminSession.MONITORING);

        DynaActionForm netwkForm = (DynaActionForm) iActionForm;

        List<ServerBean> startedServers = new ArrayList<ServerBean>();
        List<ServerBean> stoppedServers = new ArrayList<ServerBean>();

        // get servers list
        NewJMXService jmxService = NewJMXService.getJmxService();
        List<Map<String, String>> serversList = jmxService.getRawServersList();
        if (serversList != null && serversList.size() > 0) {
            // transform raw servers into beans
            for (Map<String, String> mapServer : serversList) {
                ServerBean beanServer = new ServerBean();
                beanServer.setName(mapServer.get("name"));
                beanServer.setHost(mapServer.get("host"));
                beanServer.setJmxPort(mapServer.get("jmxPort"));
                beanServer.setJmxLogin(mapServer.get("jmxLogin"));
                beanServer.setJmxPassword(mapServer.get("jmxPassword"));
                beanServer.setState(mapServer.get("state"));
                beanServer.setMonitor(mapServer.get("monitor"));
                beanServer.setShowMessageContent(mapServer
                    .get("showMessageContent"));
                if (beanServer.getState().equalsIgnoreCase(PetalsAdminServiceMBean.STATE_STARTED)) {
                    // search server's components
                    Map<String, Map<String, Object>> mapComponents = jmxService
                        .getRawComponents(mapServer.get("name"));
                    if ((mapComponents != null) && (mapComponents.size() > 0)) {
                        List<ComponentBean> serverComponents = new ArrayList<ComponentBean>();
                        // transform raw components into beans
                        for (String compoName : mapComponents.keySet()) {
                            // create bean
                            ComponentBean beanCompo = new ComponentBean();
                            // get raw component
                            Map<String, Object> mapCompo = mapComponents
                                .get(compoName);
                            // register params in bean
                            beanCompo.setName(compoName);
                            beanCompo.setObjectName((ObjectName) mapCompo
                                .get("objectName"));
                            beanCompo.setType((String) mapCompo.get("type"));
                            beanCompo.setState((String) mapCompo.get("state"));
                            beanCompo.setDescription((String) mapCompo
                                .get("description"));
                            // add bean to list
                            serverComponents.add(beanCompo);
                        }
                        // add list to server bean
                        beanServer.setComponents(serverComponents);
                    }
                    // add server to started list
                    startedServers.add(beanServer);
                } else {
                    // add server to stopped list
                    stoppedServers.add(beanServer);
                }
            }
        }

        netwkForm.set("startedServers", startedServers);
        netwkForm.set("stoppedServers", stoppedServers);
        return iActionMapping.findForward("success");
    }

}
