/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.webadmin.util;
import java.io.IOException;
import java.io.InputStream;

import org.jdom.Document;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;

/**
 * @author mcarpentier
 *
 * Load an XML configuration file
 */
public class ConfigHelper {

    
    /**
     * Read the portal configuration Document
     * @return the portal configuration Document
     * @throws ConfigHelperException if configuration file was not found
     * @throws JDOMException if an error occured while parsing the configuration file
     */
    public static Document getConfig(String XMLfile) throws Exception  {
        Document doc = null;
        String myFile = StringHelper.isNullOrEmpty(XMLfile) ? "mapsite.xml" : XMLfile;
        InputStream myInputStream  = ConfigHelper.class.getResourceAsStream(myFile);
        if (myInputStream == null) 
            myInputStream  = ConfigHelper.class.getResourceAsStream("/"+myFile);
        if (myInputStream == null) {
            //TODO : log
            throw new ExceptionInInitializerError("unable to find configuration file");
        }
        try {
            doc =parseXmlFile(myInputStream);   
        } catch (JDOMException e) {
            throw new Exception("Error in JDOM parsing", e);
            
        }
        return doc;
        
    }
    
    /**
     * TODO : check if XML file is following its DTD ?
     */
    public boolean isValid(String XMLfile) {
        return true;
    }
    
    /**
     * Parse an xml file to produce a Document object mapping this xml template
     * @param xmlURL the InputStream loaded from the XML document
     * @return the JDOM document
     * @throws IOException 
     */
    private static Document parseXmlFile(InputStream xmlURL) throws JDOMException, IOException {
        Document document = null;
        SAXBuilder sxb = new SAXBuilder();
        document = sxb.build(xmlURL);
        document.getRootElement();
        return document;
    }

}
