/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: JBIEntity.java msauvage $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.webadmin.util;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;

import javax.management.ObjectName;

/**
 * This class represents a jbi entity
 * 
 * @author ddesjardins - eBMWebsourcing
 */
public class JBIEntity {

    /**
     * Binding component type
     */
    public static final String BINDING_COMPONENT = "Binding component";

    /**
     * Service assembly type
     */
    public static final String SERVICE_ASSEMBLY = "Service assembly";

    /**
     * Service engine type
     */
    public static final String SERVICE_ENGINE = "Service engine";

    private static final String DESCRIPTION = "description";

    private static final String NAME = "name";

    private static final String OBJECTNAME = "objectName";

    private static final String STATE = "state";

    private static final String TYPE = "type";

    /**
     * Description of the entity
     */
    private String description;

    /**
     * Name of the entity
     */
    private String name;

    /**
     * JMX ObjectName
     */
    private ObjectName objectName;

    /**
     * List of service units
     */
    private Set<String> serviceUnits = new TreeSet<String>();

    /**
     * State of the entity
     */
    private String state;

    /**
     * Type of entity
     */
    private String type;

    public JBIEntity() {
    }

    /**
     * constructs a new JBIEntity with datas given in a Map
     * 
     * @param map
     */
    public JBIEntity(Map<String, Object> map) {
        this.name = map.get(NAME).toString();
        this.state = map.get(STATE).toString();
        this.type = map.get(TYPE).toString();
        this.objectName = (ObjectName) map.get(OBJECTNAME);
        this.description = map.get(DESCRIPTION).toString();
    }

    public String getDescription() {
        return description;
    }

    public String getName() {
        return name;
    }

    public ObjectName getObjectName() {
        return objectName;
    }

    public Set<String> getServiceUnits() {
        return serviceUnits;
    }

    public String getState() {
        return state;
    }

    public String getType() {
        return type;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public void setName(String name) {
        this.name = name;
    }

    public void setObjectName(ObjectName objectName) {
        this.objectName = objectName;
    }

    public void setServiceUnits(Set<String> serviceUnits) {
        this.serviceUnits = serviceUnits;
    }

    public void setState(String state) {
        this.state = state;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Map<String, Object> toMap() {
        Map<String, Object> compoHash = new HashMap<String, Object>();
        compoHash.put(NAME, this.name);
        compoHash.put(STATE, this.state);
        compoHash.put(TYPE, this.type);
        compoHash.put(OBJECTNAME, this.objectName);
        compoHash.put(DESCRIPTION, this.description);
        return compoHash;
    }

}
