/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: MathTools.java msauvage $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.webadmin.util;

/**
 * some mathematics usefull methods...
 */
public final class MathTools {

    public static final int HUNDRED = 100;

    public static final int TEN = 10;

    public static final int THOUSAND = 1000;

    private static final double HALF = 0.5;

    private static final double HUNDRED_DOUBLE = 100.00;

    private MathTools() {
    }

    /**
     * Returns the maximum element of an array of long numbers
     * 
     * @param numbers
     *            array of long numbers
     * @return the biger number
     */
    public static long elementMax(Long[] numbers) {
        long max = numbers[0];
        for (int i = 1; i < numbers.length; i++) {
            if (numbers[i] > max) {
                max = numbers[i];
            }
        }
        return max;
    }

    /**
     * Returns the minimum element of an array of long numbers
     * 
     * @param numbers
     *            array of long numbers
     * @return the smaller number
     */
    public static long elementMin(Long[] numbers) {
        long min = numbers[0];
        for (int i = 1; i < numbers.length; i++) {
            if (numbers[i] < min) {
                min = numbers[i];
            }
        }
        return min;
    }

    /**
     * Returns a number of elements per second
     * 
     * @param time
     *            time elapsed
     * @param nbElem
     *            total number of elements
     * @return the average as a double
     */
    public static double nbPerSec(long time, int nbElem) {
        double nbElemSec = (double) nbElem / time;
        return (Math.round(nbElemSec * Math.pow(TEN, 2))) / (Math.pow(TEN, 2));
    }

    /**
     * Returns the value as a percentage of the total
     * 
     * @param value
     *            number to transform
     * @param total
     *            reference number
     * @return the percentage as a double
     */
    public static double percent(int value, int total) {
        double perc = value * HUNDRED_DOUBLE / total;
        return (Math.round(perc * Math.pow(TEN, 2))) / (Math.pow(TEN, 2));
    }

    public static double round(double number, int precision) {
        return (double) ((int) (number * Math.pow(TEN, precision) + HALF))
            / Math.pow(TEN, precision);
    }
}
