package org.objectweb.petals.tools.webadmin.util;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

import javax.management.Notification;
import javax.management.NotificationListener;

import org.objectweb.petals.tools.webadmin.bo.Message;
import org.objectweb.petals.tools.webadmin.bo.MessageExchange;
import org.objectweb.petals.tools.webadmin.collector.DataCollector;
import org.objectweb.petals.tools.webadmin.collector.ExchangesStorage;

public class MessagesListener implements NotificationListener {

    DataCollector collector;

    // object for dates formating
    private static final DateFormat DATE_FORMATER = new SimpleDateFormat(
        "dd MMM yyyy, HH:mm:ss");

    public MessagesListener(DataCollector collector) {
        this.collector = collector;
    }

    /**
     * @see NotificationListener#handleNotification(Notification, Object)
     */
    @SuppressWarnings("unchecked")
    public void handleNotification(Notification notification, Object handback) {
        Object userData = notification.getUserData();
        if (userData instanceof ArrayList) {
            List<Map<String, Object>> messages = (ArrayList<Map<String, Object>>) userData;
            List<Message> list = rawToMessageList(messages);
               collector.storeMessages(list,Long.toString(notification.getSequenceNumber()));
               collector.processNewDatas(list);
         } else {
            log("ERROR", "Notification #" + notification.getSequenceNumber()
                + " : userData aren't messages - datas instance of "
                + userData.getClass().getName());
        }
    }

    /**
     * Transforms a list of Map<String, Object> representations of messages
     * into a list of Message object representations of messages
     * 
     * @param rawList
     *            the list of Map messages
     * @return a list of Message
     */
    private List<Message> rawToMessageList(List<Map<String, Object>> rawList) {
        List<Message> messagesList = new ArrayList<Message>();
        for (Map<String, Object> message : rawList) {
            messagesList.add(new Message(message));
        }
        return messagesList;
    }

    private void log(String level, String message) {
        System.out.println("[WEBADMIN " + level + "] "
            + DATE_FORMATER.format(new Date().getTime()) + " : " + message);
    }

}
